==> funcoeszz_18.3.orig.tar.gz: funcoeszz-18.3/testador/zzjquery.sh <==
$ zzjquery
jQuery

jQuery( selector [, context ] )
Description: Accepts a string containing a CSS selector which is then used to match a set of elements.

jQuery( selector [, context ] )
selector
A string containing a selector expression
context
A DOM Element, Document, or jQuery to use as context

jQuery( element )
element
A DOM element to wrap in a jQuery object.

jQuery( elementArray )
elementArray
An array containing a set of DOM elements to wrap in a jQuery object.

jQuery( object )
object
A plain object to wrap in a jQuery object.

jQuery( selection )
selection
An existing jQuery object to clone.

jQuery()
This signature does not accept any arguments.

jQuery( html [, ownerDocument ] )
Description: Creates DOM elements on the fly from the provided string of raw HTML.

jQuery( html [, ownerDocument ] )
html
A string of HTML to create on the fly. Note that this parses HTML, not XML.
ownerDocument
A document in which the new elements will be created.

jQuery( html, attributes )
html
A string defining a single, standalone, HTML element (e.g. &lt;div/&gt; or &lt;div&gt;&lt;/div&gt;).
attributes
An object of attributes, events, and methods to call on the newly-created element.

jQuery( callback )
Description: Binds a function to be executed when the DOM has finished loading.

jQuery( callback )
callback
The function to execute when the DOM is ready.

$

$ zzjquery --categoria
Ajax
Attributes
Callbacks Object
Core
CSS
Data
Deferred Object
Deprecated
Dimensions
Effects
Events
Forms
Internals
Manipulation
Miscellaneous
Offset
Properties
Removed
Selectors
Traversing
Utilities
Version
$

$ zzjquery --lista css
.addClass
.css
.hasClass
.height
.innerHeight
.innerWidth
jQuery.cssHooks
jQuery.cssNumber
jQuery.escapeSelector
.offset
.outerHeight
.outerWidth
.position
.removeClass
.scrollLeft
.scrollTop
.toggleClass
.width
$

$ zzjquery --lista Ajax
.ajaxComplete
.ajaxError
.ajaxSend
.ajaxStart
.ajaxStop
.ajaxSuccess
jQuery.ajax
jQuery.ajaxPrefilter
jQuery.ajaxSetup
jQuery.ajaxTransport
jQuery.get
jQuery.getJSON
jQuery.getScript
jQuery.param
jQuery.post
.load
.serialize
.serializeArray
$

$ zzjquery get
get

.get( index )
Description: Retrieve one of the elements matched by the jQuery object.

.get( index )
index
A zero-based integer indicating which element to retrieve.

.get()
Description: Retrieve the elements matched by the jQuery object.

.get()
This method does not accept any arguments.

$


$ zzjquery -s get
get

.get( index )

.get()

$

==> funcoeszz_21.1.orig.tar.gz: funcoeszz-21.1/testador/zzjquery.sh <==
$ zzjquery
jQuery

jQuery( selector [, context ] )
Description: Accepts a string containing a CSS selector which is then used to match a set of elements.

jQuery( selector [, context ] )
selector
A string containing a selector expression
context
A DOM Element, Document, jQuery or selector to use as context

jQuery( element )
element
A DOM element to wrap in a jQuery object.

jQuery( elementArray )
elementArray
An array containing a set of DOM elements to wrap in a jQuery object.

jQuery( object )
object
A plain object to wrap in a jQuery object.

jQuery( selection )
selection
An existing jQuery object to clone.

jQuery()
This signature does not accept any arguments.

jQuery( html [, ownerDocument ] )
Description: Creates DOM elements on the fly from the provided string of raw HTML.

jQuery( html [, ownerDocument ] )
html
A string of HTML to create on the fly. Note that this parses HTML, not XML.
ownerDocument
A document in which the new elements will be created.

jQuery( html, attributes )
html
A string defining a single, standalone, HTML element (e.g. &lt;div/&gt; or &lt;div&gt;&lt;/div&gt;).
attributes
An object of attributes, events, and methods to call on the newly-created element.

jQuery( callback )
Description: Binds a function to be executed when the DOM has finished loading.

jQuery( callback )
callback
The function to execute when the DOM is ready.

$

$ zzjquery --categoria
Ajax
Attributes
Callbacks Object
Core
CSS
Data
Deferred Object
Deprecated
Dimensions
Effects
Events
Forms
Internals
Manipulation
Miscellaneous
Offset
Properties
Removed
Selectors
Traversing
Utilities
Version
$

$ zzjquery --lista css
.addClass
.css
.hasClass
.height
.innerHeight
.innerWidth
jQuery.cssHooks
jQuery.cssNumber
jQuery.escapeSelector
.offset
.outerHeight
.outerWidth
.position
.removeClass
.scrollLeft
.scrollTop
.toggleClass
.width
$

$ zzjquery --lista Ajax
.ajaxComplete
.ajaxError
.ajaxSend
.ajaxStart
.ajaxStop
.ajaxSuccess
jQuery.ajax
jQuery.ajaxPrefilter
jQuery.ajaxSetup
jQuery.ajaxTransport
jQuery.get
jQuery.getJSON
jQuery.getScript
jQuery.param
jQuery.post
.load
.serialize
.serializeArray
$

$ zzjquery get
get

.get( index )
Description: Retrieve one of the elements matched by the jQuery object.

.get( index )
index
A zero-based integer indicating which element to retrieve.

.get()
Description: Retrieve the elements matched by the jQuery object.

.get()
This method does not accept any arguments.

$


$ zzjquery -s get
get

.get( index )

.get()

$
